/// <reference types="node" />
import { EventEmitter } from "events";
import { Comparator } from "./comparator";
import { Node } from "./node";
export declare abstract class Collection<T> extends EventEmitter {
    protected _comparator: Comparator<T>;
    protected _first: any;
    protected _last: any;
    protected _length: number;
    protected _nil: Node<T>;
    protected _root: any;
    /**
     * Base class constructor for all collection classes.
     * @param comparator {Function} a comparator function used for searching within
     * the container.
     * @constructor
     */
    constructor(comparator?: Comparator<T>);
    /**
     * @return {T} the last (max) data element from the tree.
     */
    get back(): T;
    /**
     * @return {boolean} return true if the list has no nodes, otherwise false
     */
    get empty(): boolean;
    get end(): T;
    /**
     * @returns {T} the first (min) data element from the tree.
     */
    get first(): T;
    /**
     * @returns {T} the front (min) data element from the tree.
     */
    get front(): T;
    /**
     * @return {T} the last (max) data element from the tree.
     */
    get last(): T;
    /**
     * @return {number} the number of nodes in this collection
     */
    get length(): number;
    /**
     * @return {Node<T>} the reference to the nil sentinel
     */
    get nil(): Node<T>;
    /**
     * @return {Node<T>} the front/first node in the collection
     */
    get root(): Node<T>;
    /**
     * @return {number} the number of nodes in this collection
     */
    get size(): number;
    /**
     * Initializes the object to an empty state
     */
    clear(): void;
    /**
     * Checks the container for the existence of a given object.  This is
     * a simple linear search.
     * @param obj {Object} the item to find in the container.
     * @returns {boolean} true if the item is found, otherwise false.
     */
    contains(obj: T): boolean;
    /**
     * Checks if the container is empty.
     * @returns {boolean} true if the container is empty, otherwise false.
     */
    isEmpty(): boolean;
}
