import { Comparator } from "./comparator";
import { Queue } from "./queue";
/** A double ended Queue class */
export declare class Deque<T> extends Queue<T> {
    private _maxSize;
    /**
     * The deque can be unlimited in size (default) or set to a maxium size
     * when constructed.  When the max size is exceeded, then the front item is
     * automatically removed from the queue and the new item is placed in the
     * queue (depending on  which type of insert is calld).
     * @param maxSize=0 {number} - The maximum size for this queue.
     * @param arr=[] {T[]} - An array of initial input values
     * @param comparator {Function} - a comparator function used for searching within
     * the container.
     * @constructor
     */
    constructor(maxSize?: number, arr?: T[], comparator?: Comparator<T>);
    /**
     * Checks the current internals for an overflow condition.  This occurs
     * when the maxSize storage size will be exceeded on the next insert
     * operation.
     * @returns {boolean} true if in an overflow condition, otherwise false.
     */
    get overflow(): boolean;
    /**
     * Adds an item to the end of the queue.  Checks for an overflow condition
     * and acts if one is detected.
     * @param data {Object} the data item to add to the queue.
     */
    enqueue(data: T): void;
    /**
     * Inserts a data element to the front of the queue.  Checks for an
     * overflow condition and acts if one is detected.
     * @param data {Object} the data item to add to the queue.
     */
    pushFront(data: T): void;
    /**
     * Adds an item to the end of the queue.  Checks for an overflow condition
     * and acts if one is detected.
     * @param data {Object} the data item to add to the queue.
     */
    pushBack(data: T): void;
    /**
     * Returns the first item from the queue and removes it.
     * @returns {Object} the data value on the front of the queue.
     */
    popFront(): T;
    /**
     * Retrieves the last item from the queue and removes it.
     * @returns {Object} the data value on the back of the queue.
     */
    popBack(): T;
}
