import { Comparator } from "./comparator";
import { List } from "./list";
import { Node } from "./node";
/** Simple FIFO queue implementation */
export declare class Queue<T> extends List<T> {
    protected _end: Node<T>;
    constructor(arr?: T[], comparator?: Comparator<T>);
    /**
     * Removes and returns the item at the front of the queue.
     * @returns {T} the data at the front of the queue.
     */
    dequeue(): T;
    /**
     * Removes all items from the queue in order and returns them as an
     * array of data values.
     * @returns {Array} a list of queue items as an array.
     */
    drain(): T[];
    /**
     * Searches the queue for the requested data element and removes it
     * from the queue.
     * @param data {Object} the data element that should be removed from
     * the queue.
     */
    eject(data: T): T;
    /**
     * Adds an item to the end of the queue.
     * @param data {Object} the data to insert into the queue.
     */
    enqueue(data: T): void;
    /**
     * Override wrapper for the push function from the inherited stack.  A
     * stack always pushes to the front.  The general queue should always push
     * to the end of the structure.
     * @param data {Object} the data to push on the end of the queue.
     */
    push: (data: T) => void;
}
